@@ -1,7 +1,7 @@
 from dataclasses import dataclass
 
 from arrow_bpmn.__spi__.action import Action
-from arrow_bpmn.__spi__.registry import NodeRef
+from arrow_bpmn.__spi__.registry.node_ref import NodeRef
 
 
 @dataclass
