@@ -1,6 +1,5 @@
 from dataclasses import dataclass, field
-from pathlib import Path
-from typing import Union, Optional, List
+from typing import Optional, List
 
 from arrow_dmn.engine.sync_dmn_engine import SyncDmnEngine
 
@@ -12,18 +11,19 @@ from arrow_bpmn.__spi__.factory.business_rule_factory import BusinessRuleFactory
 from arrow_bpmn.__spi__.factory.script_factory import ScriptFactory
 from arrow_bpmn.__spi__.factory.service_factory import NoOpServiceFactory
 from arrow_bpmn.__spi__.registry.event import Event
+from arrow_bpmn.__spi__.types import BpmnSource
 from arrow_bpmn.engine.event.eager_event_emitter import EagerEventEmitter
 from arrow_bpmn.engine.execution.cacheable_script_factory import CacheableScriptFactory
+from arrow_bpmn.engine.interceptor.abstract_bpmn_engine_interceptor import BpmnEngineInterceptor
+from arrow_bpmn.engine.interceptor.arrow_extension_interceptor import ArrowExtensionInterceptor
 from arrow_bpmn.engine.listener.abstract_bpmn_engine_listener import BpmnEngineListener
 from arrow_bpmn.engine.registry.abstract_event_registry import EventRegistry, ProcessRef
 from arrow_bpmn.engine.registry.inmemory_event_registry import InMemoryEventRegistry
 from arrow_bpmn.engine.store.abstract_process_store import ProcessStore
-from arrow_bpmn.engine.store.inmemory_process_story import InMemoryProcessStore
-from arrow_bpmn.parser.abstract_bpmn_parser import BpmnParser
+from arrow_bpmn.engine.store.inmemory_process_store import InMemoryProcessStore
+from arrow_bpmn.parser.abstract_parser import BpmnParser
 from arrow_bpmn.parser.xml.xml_bpmn_parser import XmlBpmnParser
 
-BpmnSource = Union[Path]
-
 
 @dataclass
 class BpmnEngine:
@@ -36,6 +36,7 @@ class BpmnEngine:
     script_factory: ScriptFactory = field(default_factory=lambda: CacheableScriptFactory(128))
     service_factory: ServiceFactory = field(default_factory=lambda: NoOpServiceFactory())
     business_rule_factory: BusinessRuleFactory = field(default_factory=lambda: SyncDmnEngine())
+    interceptor: BpmnEngineInterceptor = field(default_factory=lambda: ArrowExtensionInterceptor())
 
     def __post_init__(self):
         self.factories = BpmnFactories(self.script_factory, self.service_factory, self.business_rule_factory)
