@@ -64,7 +64,7 @@ class SequentialBpmnEngine(BpmnEngine):
         # Continue Action
         # ***************
         if isinstance(action, ContinueAction):
-            node = env.get_node(action.id)
+            node = self.interceptor(env.get_node(action.id))
             assert node is not None, f"no node found with id {action.id}"
 
             node_ref = NodeRef(env.group, state.reference.process_id, action.id, str(uuid.uuid4()), str(uuid.uuid4()))
