@@ -1,5 +1,5 @@
 from arrow_bpmn.__spi__ import State, NodeRef
-from arrow_bpmn.engine.abstract_engine import ProcessRef
+from arrow_bpmn.__spi__.registry.process_ref import ProcessRef
 from arrow_bpmn.model.process import Process
 
 
