@@ -32,7 +32,7 @@ class ExclusiveGateway(BpmnNode):
 
     @property
     def default(self):
-        return self.__dict__["default"]
+        return self._get_property("default")
 
     def execute(self, state: State, environment: Environment) -> Tuple[State, Actions]:
         # try to find a sequence by expression
