@@ -55,18 +55,18 @@ class Process(EventRegistryAware):
 
     def to_json(self):
         import json
-        return json.dumps(self.to_json2(self))
+        return json.dumps(self._to_json(self))
 
-    def to_json2(self, object) -> dict:
+    def _to_json(self, object) -> dict:
         obj = {}
 
         for k in (object.__dict__ if not isinstance(object, dict) else object):
             value = object.__dict__[k] if not isinstance(object, dict) else object[k]
             if type(value) == list:
-                obj[k] = [{"type": type(x).__name__, "item": self.to_json2(x)} for x in value]
+                obj[k] = [{"type": type(x).__name__, "item": self._to_json(x)} for x in value]
             elif type(value) == dict:
                 obj[k] = {"type": type(value).__name__}
-                result = self.to_json2(value)
+                result = self._to_json(value)
                 obj[k]["item"] = result["item"] if "item" in result else {}
             elif isinstance(value, UserDict):
                 obj[k] = {"type": type(value).__name__, "item": value.data}
