@@ -6,7 +6,6 @@ from arrow_bpmn.__spi__.action import ContinueAction, Actions, QueueAction
 from arrow_bpmn.__spi__.execution import Environment
 from arrow_bpmn.__spi__.execution import State
 from arrow_bpmn.engine.registry.abstract_event_registry import ManualEvent
-from arrow_bpmn.parser.xml.xml_element import XMLElement
 
 
 class ManualTask(BpmnNode):
@@ -16,7 +15,7 @@ class ManualTask(BpmnNode):
     is handled as a pass-through activity, automatically continuing the process when the process execution arrives at it.
     """
 
-    def __init__(self, element: XMLElement):
+    def __init__(self, element: dict):
         super().__init__(element)
 
     # noinspection PyBroadException
