@@ -25,7 +25,7 @@ from arrow_bpmn.model.task.script_task import ScriptTask
 from arrow_bpmn.model.task.send_task import SendTask
 from arrow_bpmn.model.task.service_task import ServiceTask
 from arrow_bpmn.model.task.user_task import UserTask
-from arrow_bpmn.parser.abstract_bpmn_parser import BpmnParser
+from arrow_bpmn.parser.abstract_parser import BpmnParser
 from arrow_bpmn.parser.xml.xml_element import XMLElement
 
 DiagramSource = Path
@@ -44,20 +44,23 @@ class XmlBpmnParser(BpmnParser):
         return "customGroup", [self._parse_process(x, events) for x in root.get_tags("./bpmn:process")]
 
     def _parse_process(self, process: XMLElement, events: EventDict) -> Process:
-        sequence_flows = [SequenceFlow.from_xml(x) for x in process.get_tags("bpmn:sequenceFlow")]
-        tasks = [ScriptTask.from_xml(x) for x in process.get_tags("bpmn:scriptTask")]
-        tasks += [UserTask(x.get_attributes()) for x in process.get_tags("bpmn:userTask")]
-        tasks += [ManualTask(x.get_attributes()) for x in process.get_tags("bpmn:manualTask")]
-        tasks += [ReceiveTask(x.get_attributes()) for x in process.get_tags("bpmn:receiveTask")]
-        tasks += [SendTask(x.get_attributes()) for x in process.get_tags("bpmn:sendTask")]
-        tasks += [ServiceTask(x) for x in process.get_tags("bpmn:serviceTask")]
-        tasks += [BusinessRuleTask.from_xml(x) for x in process.get_tags("bpmn:businessRuleTask")]
+        def get_attributes(node: XMLElement):
+            return self._concat_dicts(node.get_attributes(), self.extension.parse_xml(node))
+
+        sequence_flows = [self._parse_sequence_flow(x) for x in process.get_tags("bpmn:sequenceFlow")]
+        tasks = [self._parse_script_task(x) for x in process.get_tags("bpmn:scriptTask")]
+        tasks += [UserTask(get_attributes(x)) for x in process.get_tags("bpmn:userTask")]
+        tasks += [ManualTask(get_attributes(x)) for x in process.get_tags("bpmn:manualTask")]
+        tasks += [ReceiveTask(get_attributes(x)) for x in process.get_tags("bpmn:receiveTask")]
+        tasks += [SendTask(get_attributes(x)) for x in process.get_tags("bpmn:sendTask")]
+        tasks += [ServiceTask(get_attributes(x)) for x in process.get_tags("bpmn:serviceTask")]
+        tasks += [BusinessRuleTask(get_attributes(x)) for x in process.get_tags("bpmn:businessRuleTask")]
         tasks += [self._parse_call_activity(x) for x in process.get_tags("bpmn:callActivity")]
         tasks += [self._parse_custom_task(x, events) for x in process.get_tags("bpmn:task")]
         start_events = [self._parse_start_event(x, events) for x in process.get_tags("bpmn:startEvent")]
         end_events = [self._parse_end_event(x, events) for x in process.get_tags("bpmn:endEvent")]
         boundary_events = [self._parse_boundary_event(x, events) for x in process.get_tags("bpmn:boundaryEvent")]
-        gateways = [ExclusiveGateway(x) for x in process.get_tags("bpmn:exclusiveGateway")]
+        gateways = [ExclusiveGateway(x.get_attributes()) for x in process.get_tags("bpmn:exclusiveGateway")]
 
         ie1 = [self._parse_intermediate_catch_event(x, events) for x in process.get_tags("bpmn:intermediateCatchEvent")]
         ie2 = [self._parse_intermediate_throw_event(x, events) for x in process.get_tags("bpmn:intermediateThrowEvent")]
@@ -66,6 +69,12 @@ class XmlBpmnParser(BpmnParser):
         return Process(process.get_attributes(), sequence_flows, tasks, start_events, end_events, boundary_events,
                        intermediate_events, gateways, events)
 
+    def _parse_sequence_flow(self, element: XMLElement):
+        if element.has_tag("bpmn:conditionExpression"):
+            expression = element.get_tag("bpmn:conditionExpression")
+            return SequenceFlow(element.get_attributes(), expression.get_text())
+        return SequenceFlow(element.get_attributes(), None)
+
     def _parse_custom_task(self, task: XMLElement, events: EventDict):
         raise ValueError("no task event specification found")
 
@@ -140,11 +149,19 @@ class XmlBpmnParser(BpmnParser):
 
         raise ValueError(f"cannot parse boundary event {event}")
 
+    def _parse_script_task(self, element: XMLElement):
+        attributes = self._concat_dicts(element.get_attributes(), self.extension.parse_xml(element))
+        attributes["varName"] = element["arrow:varName"] or "result"
+        attributes["scriptFormat"] = element["scriptFormat"]
+        attributes["script"] = element.get_tag("bpmn:script").get_text(True)
+
+        return ScriptTask(attributes)
+
     def _parse_call_activity(self, element: XMLElement):
         def parse_mappings(e: XMLElement):
             mappings = []
-            mappings.extend([VariableMapping(x["source"], x["target"]) for x in e.get_tags("xy:variable")])
-            mappings.extend([ExpressionMapping(x["source"], x["target"]) for x in e.get_tags("xy:expression")])
+            mappings.extend([VariableMapping(x["source"], x["target"]) for x in e.get_tags("arrow:variable")])
+            mappings.extend([ExpressionMapping(x["source"], x["target"]) for x in e.get_tags("arrow:expression")])
             return mappings
 
         incoming_state = []
@@ -152,9 +169,10 @@ class XmlBpmnParser(BpmnParser):
 
         extensions = element.get_tags("bpmn:extensionElements")
         for extension in extensions:
-            for state_mapping in extension.get_tags("xy:incomingState"):
+            for state_mapping in extension.get_tags("arrow:incomingState"):
                 incoming_state.extend(parse_mappings(state_mapping))
-            for state_mapping in extension.get_tags("xy:outgoingState"):
+            for state_mapping in extension.get_tags("arrow:outgoingState"):
                 outgoing_state.extend(parse_mappings(state_mapping))
 
-        return CallActivity(element.get_attributes(), incoming_state, outgoing_state)
+        attributes = self._concat_dicts(element.get_attributes(), self.extension.parse_xml(element))
+        return CallActivity(attributes, incoming_state, outgoing_state)
