@@ -3,8 +3,7 @@ from typing import List, Optional
 
 NAMESPACES = {
     "bpmn": "http://www.omg.org/spec/BPMN/20100524/MODEL",
-    "xy": "http://www.x-and-y.ai/schema/bpmn/xy",
-    "dmn": "https://www.omg.org/spec/DMN/20191111/MODEL/"
+    "arrow": "http://www.x-and-y.ai/schema/bpmn/arrow"
 }
 
 
@@ -13,15 +12,15 @@ class XMLElement:
     def __init__(self, element: XmlTree.Element):
         self.element = element
 
-    def get_tags(self, tag: str) -> List['XMLElement']:
-        elements = self.element.findall(tag, NAMESPACES)
+    def get_tags(self, tag: str, namespaces: Optional[dict] = None) -> List['XMLElement']:
+        elements = self.element.findall(tag, namespaces or NAMESPACES)
         return list(map(lambda x: XMLElement(x), elements))
 
-    def has_tag(self, tag: str) -> bool:
-        return self.get_tag(tag) is not None
+    def has_tag(self, tag: str, namespaces: Optional[dict] = None) -> bool:
+        return self.get_tag(tag, namespaces) is not None
 
-    def get_tag(self, tag: str) -> Optional['XMLElement']:
-        elements = self.element.findall(tag, NAMESPACES)
+    def get_tag(self, tag: str, namespaces: Optional[dict] = None) -> Optional['XMLElement']:
+        elements = self.element.findall(tag, namespaces or NAMESPACES)
         if len(elements) == 0:
             return None
         return next(map(lambda x: XMLElement(x), elements))
@@ -29,12 +28,12 @@ class XMLElement:
     def get_attributes(self):
         return {x[0]: x[1] for x in self.element.items()}
 
-    def get_attribute(self, name: str) -> Optional[str]:
+    def get_attribute(self, name: str, namespaces: Optional[dict] = None) -> Optional[str]:
         attributes = self.get_attributes()
 
         if ":" in name:
             array = name.split(":")
-            namespace = NAMESPACES[array[0]]
+            namespace = (namespaces or NAMESPACES)[array[0]]
             key = "{" + namespace + "}" + array[1]
             return attributes[key] if key in attributes else None
 
@@ -47,4 +46,4 @@ class XMLElement:
         return self.element.text.strip()
 
     def __getitem__(self, item):
-        return self.get_attribute(item)
\ No newline at end of file
+        return self.get_attribute(item)
